@@ -1,8 +1,9 @@
 """Client for API v.1.9."""
-from .client import Client, APIError
+from .client import Client
 from .cart import Cart, CartItem
 from .currency import Currency
 from .payment import (
+    APIError,
     PaymentInfo,
     PaymentMethod,
     PaymentOperation,
@@ -10,3 +11,12 @@ from .payment import (
 )
 from .webpage import WebPageAppearanceConfig, WebPageLanguage
 from .key import RSAKey, FileRSAKey, CachedRSAKey
+from .signature import InvalidSignatureError
+from .http import (
+    HTTPClient,
+    HTTPConnectionError,
+    HTTPRequestError,
+    HTTPResponse,
+    HTTPTimeoutError,
+    RequestsHTTPClient,
+)
