@@ -23,21 +23,6 @@ class ReturnMethod(Enum):
     GET = "GET"
 
 
-class APIError(Exception):
-    """API error."""
-
-    def __init__(self, code: int, message: str) -> None:
-        """Init API error.
-
-        :param code: error code
-        :message: error message
-        :status_detail: status detail
-        """
-        self.code = code
-        self.message = message
-        super().__init__(f"{self.code}: {self.message}")
-
-
 class Client:
     """API client."""
 
@@ -46,7 +31,7 @@ class Client:
         merchant_id: str,
         private_key: Union[str, RSAKey],
         public_key: Union[str, RSAKey],
-        base_url: str = "https://iapi.iplatebnibrana.csob.cz/api/v1.9",
+        base_url: str = "https://api.platebnibrana.csob.cz/api/v1.9",
         http_client: HTTPClient = RequestsHTTPClient(),
     ) -> None:
         # pylint:disable=too-many-arguments
@@ -94,9 +79,16 @@ class Client:
             raise ValueError('"return_url" must be up to 300 chars')
         if customer_id and len(customer_id) > 50:
             raise ValueError('"customer_id" must be up to 50 chars')
+        if total_amount <= 0:
+            raise ValueError('"total_amount" must be > 0')
 
         cart = cart or Cart([CartItem("Payment", 1, total_amount)])
 
+        if cart.total_amount != total_amount:
+            raise ValueError(
+                "Cart's total amount does not match the requested total amount"
+            )
+
         payload = mk_payload(
             str(self.private_key),
             pairs=(
@@ -201,11 +193,25 @@ class Client:
         )
         return self._get_payment_info(response)
 
-    def _get_payment_info(self, response: HTTPResponse) -> PaymentInfo:
-        if response.http_success and response.data["resultCode"] == 0:
-            verify(response.data, str(self.public_key))
-            return PaymentInfo.from_response(response.data)
+    def refund_payment(
+        self, pay_id: str, amount: Optional[int] = None
+    ) -> PaymentInfo:
+        """Refund payment.
 
-        raise APIError(
-            response.data["resultCode"], response.data["resultMessage"]
+        :param pay_id: payment ID
+        :param amount: amount to refund. It must be less or equal to the
+          original amount and provided in hundredths of the base currency.
+          If not provided, the full amount will be refunded.
+        """
+        response = self._http_client.request(
+            f"{self.base_url}/payment/refund",
+            "put",
+            self._build_payload(pay_id, amount=amount),
         )
+        return self._get_payment_info(response)
+
+    def _get_payment_info(self, response: HTTPResponse) -> PaymentInfo:
+        if response.http_success:
+            verify(response.data, str(self.public_key))
+
+        return PaymentInfo.from_response(response.data)
